==> opennms-services-1.3.7-sources.jar: org/opennms/netmgt/notifd/NotifdQueueHandler.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.                                                            
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//       
// For more information contact: 
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//
// Tab Size = 8
//

package org.opennms.netmgt.notifd;

import org.opennms.core.fiber.PausableFiber;

/**
 * This interface defines a handler for a Notifd queue. As notifications are
 * parsed from events they will be put on a process queue and will be handled by
 * a class implementing this interface.
 * 
 * @author <a href="mailto:jason@opennms.org">Jason Johns </a>
 * @author <a href="http://www.opennms.org/>OpenNMS </a>
 * 
 */
public interface NotifdQueueHandler extends Runnable, PausableFiber {
    /**
     * 
     */
    public void setQueueID(String queueID);

    /**
     * 
     */
    public void setNoticeQueue(NoticeQueue queue);

    /**
     * 
     */
    public void setInterval(String interval);

    /**
     * 
     */
    public void processQueue();
}

==> opennms-services-1.8.12-sources.jar: org/opennms/netmgt/notifd/NotifdQueueHandler.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.                                                            
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//       
// For more information contact: 
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//
// Tab Size = 8
//

package org.opennms.netmgt.notifd;

import org.opennms.core.fiber.PausableFiber;

/**
 * This interface defines a handler for a Notifd queue. As notifications are
 * parsed from events they will be put on a process queue and will be handled by
 * a class implementing this interface.
 *
 * @author <a href="mailto:jason@opennms.org">Jason Johns </a>
 * @author <a href="http://www.opennms.org/>OpenNMS </a>
 * @author <a href="mailto:jason@opennms.org">Jason Johns </a>
 * @author <a href="http://www.opennms.org/>OpenNMS </a>
 * @version $Id: $
 */
public interface NotifdQueueHandler extends Runnable, PausableFiber {
    /**
     * <p>setQueueID</p>
     *
     * @param queueID a {@link java.lang.String} object.
     */
    public void setQueueID(String queueID);

    /**
     * <p>setNoticeQueue</p>
     *
     * @param queue a {@link org.opennms.netmgt.notifd.NoticeQueue} object.
     */
    public void setNoticeQueue(NoticeQueue queue);

    /**
     * <p>setInterval</p>
     *
     * @param interval a {@link java.lang.String} object.
     */
    public void setInterval(String interval);

    /**
     * <p>processQueue</p>
     */
    public void processQueue();
}
